Class: OneMsgChatApi::CallingApi
- Inherits:
-
Object
- Object
- OneMsgChatApi::CallingApi
- Defined in:
- lib/one_msg_chat_api/api/calling_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_calling_settings(token, opts = {}) ⇒ Hash<String, Object>
Get calling settings WhatsApp Calling API settings (beta).
-
#get_calling_settings_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get calling settings WhatsApp Calling API settings (beta).
-
#initialize(api_client = ApiClient.default) ⇒ CallingApi
constructor
A new instance of CallingApi.
-
#initiate_call(token, opts = {}) ⇒ Hash<String, Object>
Initiate WhatsApp call Outbound Calling API (beta).
-
#initiate_call_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Initiate WhatsApp call Outbound Calling API (beta).
-
#update_calling_settings(token, opts = {}) ⇒ Hash<String, Object>
Update calling settings Update WhatsApp Calling API settings (beta).
-
#update_calling_settings_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update calling settings Update WhatsApp Calling API settings (beta).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CallingApi
Returns a new instance of CallingApi.
19 20 21 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_calling_settings(token, opts = {}) ⇒ Hash<String, Object>
Get calling settings WhatsApp Calling API settings (beta). Requires Meta Calling enablement on the WABA. Not production-complete — paths and webhook field names may change. Trial/subscription-limited channels are blocked.
27 28 29 30 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 27 def get_calling_settings(token, opts = {}) data, _status_code, _headers = get_calling_settings_with_http_info(token, opts) data end |
#get_calling_settings_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get calling settings WhatsApp Calling API settings (beta). Requires Meta Calling enablement on the WABA. Not production-complete — paths and webhook field names may change. Trial/subscription-limited channels are blocked.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 37 def get_calling_settings_with_http_info(token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CallingApi.get_calling_settings ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling CallingApi.get_calling_settings" end # resource path local_var_path = '/callingSettings' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"CallingApi.get_calling_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CallingApi#get_calling_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#initiate_call(token, opts = {}) ⇒ Hash<String, Object>
Initiate WhatsApp call Outbound Calling API (beta). Requires Meta Calling enablement and product consent. Not production-complete — verify on stage before relying on this in production. Trial/subscription-limited channels are blocked.
92 93 94 95 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 92 def initiate_call(token, opts = {}) data, _status_code, _headers = initiate_call_with_http_info(token, opts) data end |
#initiate_call_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Initiate WhatsApp call Outbound Calling API (beta). Requires Meta Calling enablement and product consent. Not production-complete — verify on stage before relying on this in production. Trial/subscription-limited channels are blocked.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 103 def initiate_call_with_http_info(token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CallingApi.initiate_call ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling CallingApi.initiate_call" end # resource path local_var_path = '/initiateCall' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'request_body']) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"CallingApi.initiate_call", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CallingApi#initiate_call\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_calling_settings(token, opts = {}) ⇒ Hash<String, Object>
Update calling settings Update WhatsApp Calling API settings (beta). Requires Meta Calling enablement. Trial/subscription-limited channels are blocked.
163 164 165 166 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 163 def update_calling_settings(token, opts = {}) data, _status_code, _headers = update_calling_settings_with_http_info(token, opts) data end |
#update_calling_settings_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update calling settings Update WhatsApp Calling API settings (beta). Requires Meta Calling enablement. Trial/subscription-limited channels are blocked.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/one_msg_chat_api/api/calling_api.rb', line 174 def update_calling_settings_with_http_info(token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CallingApi.update_calling_settings ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling CallingApi.update_calling_settings" end # resource path local_var_path = '/callingSettings' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'request_body']) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"CallingApi.update_calling_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CallingApi#update_calling_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |