Class: OneMsgChatApi::ChannelApi
- Inherits:
-
Object
- Object
- OneMsgChatApi::ChannelApi
- Defined in:
- lib/one_msg_chat_api/api/channel_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_conversational_automation(token, opts = {}) ⇒ ConversationalAutomation
Get conversational automation settings Get WhatsApp conversational components for the channel (welcome message, ice-breaker prompts, and slash commands).
-
#get_conversational_automation_with_http_info(token, opts = {}) ⇒ Array<(ConversationalAutomation, Integer, Hash)>
Get conversational automation settings Get WhatsApp conversational components for the channel (welcome message, ice-breaker prompts, and slash commands).
-
#get_status(token, opts = {}) ⇒ Hash<String, Object>
Get channel status Returns WhatsApp Business API client connection status.
-
#get_status_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get channel status Returns WhatsApp Business API client connection status.
-
#initialize(api_client = ApiClient.default) ⇒ ChannelApi
constructor
A new instance of ChannelApi.
-
#set_conversational_automation(token, conversational_automation, opts = {}) ⇒ Hash<String, Object>
Set conversational automation settings Update WhatsApp conversational components.
-
#set_conversational_automation_with_http_info(token, conversational_automation, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Set conversational automation settings Update WhatsApp conversational components.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ChannelApi
Returns a new instance of ChannelApi.
19 20 21 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_conversational_automation(token, opts = {}) ⇒ ConversationalAutomation
Get conversational automation settings
Get WhatsApp conversational components for the channel (welcome message, ice-breaker prompts, and slash commands). Proxies Meta/360dialog GET /conversational_automation. When enable_welcome_message is true and a user opens chat for the first time, Meta delivers a webhook message with type: request_welcome. The inbound formatter exposes that as type: \"request_welcome\" and meta.request_welcome: true so your webhook can send a custom welcome reply.
27 28 29 30 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 27 def get_conversational_automation(token, opts = {}) data, _status_code, _headers = get_conversational_automation_with_http_info(token, opts) data end |
#get_conversational_automation_with_http_info(token, opts = {}) ⇒ Array<(ConversationalAutomation, Integer, Hash)>
Get conversational automation settings Get WhatsApp conversational components for the channel (welcome message, ice-breaker prompts, and slash commands). Proxies Meta/360dialog `GET /conversational_automation`. When `enable_welcome_message` is true and a user opens chat for the first time, Meta delivers a webhook message with `type: request_welcome`. The inbound formatter exposes that as `type: "request_welcome"` and `meta.request_welcome: true` so your webhook can send a custom welcome reply.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 37 def get_conversational_automation_with_http_info(token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChannelApi.get_conversational_automation ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling ChannelApi.get_conversational_automation" end # resource path local_var_path = '/conversationalAutomation' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConversationalAutomation' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"ChannelApi.get_conversational_automation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChannelApi#get_conversational_automation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_status(token, opts = {}) ⇒ Hash<String, Object>
Get channel status Returns WhatsApp Business API client connection status.
91 92 93 94 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 91 def get_status(token, opts = {}) data, _status_code, _headers = get_status_with_http_info(token, opts) data end |
#get_status_with_http_info(token, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get channel status Returns WhatsApp Business API client connection status.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 101 def get_status_with_http_info(token, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChannelApi.get_status ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling ChannelApi.get_status" end # resource path local_var_path = '/status' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"ChannelApi.get_status", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChannelApi#get_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_conversational_automation(token, conversational_automation, opts = {}) ⇒ Hash<String, Object>
Set conversational automation settings
Update WhatsApp conversational components. Allowed body fields (others are ignored): - enable_welcome_message (boolean) - prompts (string, max 4, each ≤ 80 chars) - commands ({ command_name, command_description }[]) Proxies Meta/360dialog POST /conversational_automation.
156 157 158 159 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 156 def set_conversational_automation(token, conversational_automation, opts = {}) data, _status_code, _headers = set_conversational_automation_with_http_info(token, conversational_automation, opts) data end |
#set_conversational_automation_with_http_info(token, conversational_automation, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Set conversational automation settings Update WhatsApp conversational components. Allowed body fields (others are ignored): - `enable_welcome_message` (boolean) - `prompts` (string, max 4, each ≤ 80 chars) - `commands` (` command_name, command_description `) Proxies Meta/360dialog `POST /conversational_automation`.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/one_msg_chat_api/api/channel_api.rb', line 167 def set_conversational_automation_with_http_info(token, conversational_automation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ChannelApi.set_conversational_automation ...' end # verify the required parameter 'token' is set if @api_client.config.client_side_validation && token.nil? fail ArgumentError, "Missing the required parameter 'token' when calling ChannelApi.set_conversational_automation" end # verify the required parameter 'conversational_automation' is set if @api_client.config.client_side_validation && conversational_automation.nil? fail ArgumentError, "Missing the required parameter 'conversational_automation' when calling ChannelApi.set_conversational_automation" end # resource path local_var_path = '/conversationalAutomation' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = token # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(conversational_automation) # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"ChannelApi.set_conversational_automation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ChannelApi#set_conversational_automation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |