Class: OneMsgChatApi::SendContactRequestContactsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendContactRequestContactsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgChatApi::SendContactRequestContactsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgChatApi::SendContactRequestContactsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'birthday')
    self.birthday = attributes[:'birthday']
  end

  if attributes.key?(:'addresses')
    if (value = attributes[:'addresses']).is_a?(Array)
      self.addresses = value
    end
  end

  if attributes.key?(:'emails')
    if (value = attributes[:'emails']).is_a?(Array)
      self.emails = value
    end
  end

  if attributes.key?(:'org')
    self.org = attributes[:'org']
  end

  if attributes.key?(:'phones')
    if (value = attributes[:'phones']).is_a?(Array)
      self.phones = value
    end
  end

  if attributes.key?(:'urls')
    if (value = attributes[:'urls']).is_a?(Array)
      self.urls = value
    end
  end
end

Instance Attribute Details

#addressesObject

Returns the value of attribute addresses.



22
23
24
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 22

def addresses
  @addresses
end

#birthdayObject

Returns the value of attribute birthday.



20
21
22
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 20

def birthday
  @birthday
end

#emailsObject

Returns the value of attribute emails.



24
25
26
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 24

def emails
  @emails
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 18

def name
  @name
end

#orgObject

Returns the value of attribute org.



26
27
28
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 26

def org
  @org
end

#phonesObject

Returns the value of attribute phones.



28
29
30
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 28

def phones
  @phones
end

#urlsObject

Returns the value of attribute urls.



30
31
32
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 30

def urls
  @urls
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'birthday' => :'birthday',
    :'addresses' => :'addresses',
    :'emails' => :'emails',
    :'org' => :'org',
    :'phones' => :'phones',
    :'urls' => :'urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 56

def self.openapi_types
  {
    :'name' => :'SendContactRequestContactsInnerName',
    :'birthday' => :'String',
    :'addresses' => :'Array<Object>',
    :'emails' => :'Array<Object>',
    :'org' => :'SendContactRequestContactsInnerOrg',
    :'phones' => :'Array<SendContactRequestContactsInnerPhonesInner>',
    :'urls' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      birthday == o.birthday &&
      addresses == o.addresses &&
      emails == o.emails &&
      org == o.org &&
      phones == o.phones &&
      urls == o.urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 164

def hash
  [name, birthday, addresses, emails, org, phones, urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
# File 'lib/one_msg_chat_api/models/send_contact_request_contacts_inner.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end