Class: OneMsgChatApi::SendFileRequest

Inherits:
ApiModelBase show all
Defined in:
lib/one_msg_chat_api/models/send_file_request.rb

Overview

Send file by URL/base64 or by mediaId

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendFileRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgChatApi::SendFileRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgChatApi::SendFileRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'media_id')
    self.media_id = attributes[:'media_id']
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  end

  if attributes.key?(:'voice')
    self.voice = attributes[:'voice']
  end

  if attributes.key?(:'caption')
    self.caption = attributes[:'caption']
  end

  if attributes.key?(:'quoted_msg_id')
    self.quoted_msg_id = attributes[:'quoted_msg_id']
  end

  if attributes.key?(:'chat_id')
    self.chat_id = attributes[:'chat_id']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end
end

Instance Attribute Details

#bodyObject

File source (required unless mediaId is set): - HTTP/HTTPS URL - Base64 data URI



20
21
22
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 20

def body
  @body
end

#captionObject

Returns the value of attribute caption.



34
35
36
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 34

def caption
  @caption
end

#chat_idObject

Returns the value of attribute chat_id.



38
39
40
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 38

def chat_id
  @chat_id
end

#filenameObject

File name with extension (required with body, not with mediaId)



23
24
25
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 23

def filename
  @filename
end

#media_idObject

WABA media id from uploadMedia (alternative to body)



26
27
28
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 26

def media_id
  @media_id
end

#media_typeObject

Required when using mediaId



29
30
31
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 29

def media_type
  @media_type
end

#phoneObject

Returns the value of attribute phone.



40
41
42
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 40

def phone
  @phone
end

#quoted_msg_idObject

Returns the value of attribute quoted_msg_id.



36
37
38
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 36

def quoted_msg_id
  @quoted_msg_id
end

#voiceObject

Native WhatsApp voice note (audio/ogg only)



32
33
34
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 32

def voice
  @voice
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 65

def self.attribute_map
  {
    :'body' => :'body',
    :'filename' => :'filename',
    :'media_id' => :'mediaId',
    :'media_type' => :'mediaType',
    :'voice' => :'voice',
    :'caption' => :'caption',
    :'quoted_msg_id' => :'quotedMsgId',
    :'chat_id' => :'chatId',
    :'phone' => :'phone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 90

def self.openapi_types
  {
    :'body' => :'String',
    :'filename' => :'String',
    :'media_id' => :'String',
    :'media_type' => :'String',
    :'voice' => :'Boolean',
    :'caption' => :'String',
    :'quoted_msg_id' => :'String',
    :'chat_id' => :'String',
    :'phone' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      body == o.body &&
      filename == o.filename &&
      media_id == o.media_id &&
      media_type == o.media_type &&
      voice == o.voice &&
      caption == o.caption &&
      quoted_msg_id == o.quoted_msg_id &&
      chat_id == o.chat_id &&
      phone == o.phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 233

def hash
  [body, filename, media_id, media_type, voice, caption, quoted_msg_id, chat_id, phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@caption.nil? && @caption.to_s.length > 1024
    invalid_properties.push('invalid value for "caption", the character length must be smaller than or equal to 1024.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
# File 'lib/one_msg_chat_api/models/send_file_request.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  media_type_validator = EnumAttributeValidator.new('String', ["image", "video", "audio", "document"])
  return false unless media_type_validator.valid?(@media_type)
  return false if !@caption.nil? && @caption.to_s.length > 1024
  true
end