Class: OneMsgChatApi::UsersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/one_msg_chat_api/api/users_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UsersApi

Returns a new instance of UsersApi.



19
20
21
# File 'lib/one_msg_chat_api/api/users_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/one_msg_chat_api/api/users_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#block_user(token, block_user_request, opts = {}) ⇒ SuccessResponse

Block WhatsApp user

Parameters:

  • token (String)

    JWT token or API key for authorization

  • block_user_request (BlockUserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/one_msg_chat_api/api/users_api.rb', line 27

def block_user(token, block_user_request, opts = {})
  data, _status_code, _headers = block_user_with_http_info(token, block_user_request, opts)
  data
end

#block_user_with_http_info(token, block_user_request, opts = {}) ⇒ Array<(SuccessResponse, Integer, Hash)>

Block WhatsApp user

Parameters:

  • token (String)

    JWT token or API key for authorization

  • block_user_request (BlockUserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SuccessResponse, Integer, Hash)>)

    SuccessResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/one_msg_chat_api/api/users_api.rb', line 37

def block_user_with_http_info(token, block_user_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersApi.block_user ...'
  end
  # verify the required parameter 'token' is set
  if @api_client.config.client_side_validation && token.nil?
    fail ArgumentError, "Missing the required parameter 'token' when calling UsersApi.block_user"
  end
  # verify the required parameter 'block_user_request' is set
  if @api_client.config.client_side_validation && block_user_request.nil?
    fail ArgumentError, "Missing the required parameter 'block_user_request' when calling UsersApi.block_user"
  end
  # resource path
  local_var_path = '/blockUser'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'token'] = token

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(block_user_request)

  # return_type
  return_type = opts[:debug_return_type] || 'SuccessResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['tokenAuth']

  new_options = opts.merge(
    :operation => :"UsersApi.block_user",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersApi#block_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_blocked_users(token, opts = {}) ⇒ ListBlockedUsers200Response

List blocked WhatsApp users Returns users currently blocked on this WhatsApp channel (WABA GET /block_users). Same channel token auth as blockUser / unblockUser.

Parameters:

  • token (String)

    JWT token or API key for authorization

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



100
101
102
103
# File 'lib/one_msg_chat_api/api/users_api.rb', line 100

def list_blocked_users(token, opts = {})
  data, _status_code, _headers = list_blocked_users_with_http_info(token, opts)
  data
end

#list_blocked_users_with_http_info(token, opts = {}) ⇒ Array<(ListBlockedUsers200Response, Integer, Hash)>

List blocked WhatsApp users Returns users currently blocked on this WhatsApp channel (WABA `GET /block_users`). Same channel token auth as `blockUser` / `unblockUser`.

Parameters:

  • token (String)

    JWT token or API key for authorization

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ListBlockedUsers200Response, Integer, Hash)>)

    ListBlockedUsers200Response data, response status code and response headers



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/one_msg_chat_api/api/users_api.rb', line 110

def list_blocked_users_with_http_info(token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersApi.list_blocked_users ...'
  end
  # verify the required parameter 'token' is set
  if @api_client.config.client_side_validation && token.nil?
    fail ArgumentError, "Missing the required parameter 'token' when calling UsersApi.list_blocked_users"
  end
  # resource path
  local_var_path = '/blockedUsers'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'token'] = token

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListBlockedUsers200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['tokenAuth']

  new_options = opts.merge(
    :operation => :"UsersApi.list_blocked_users",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersApi#list_blocked_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#unblock_user(token, block_user_request, opts = {}) ⇒ SuccessResponse

Unblock WhatsApp user

Parameters:

  • token (String)

    JWT token or API key for authorization

  • block_user_request (BlockUserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



164
165
166
167
# File 'lib/one_msg_chat_api/api/users_api.rb', line 164

def unblock_user(token, block_user_request, opts = {})
  data, _status_code, _headers = unblock_user_with_http_info(token, block_user_request, opts)
  data
end

#unblock_user_with_http_info(token, block_user_request, opts = {}) ⇒ Array<(SuccessResponse, Integer, Hash)>

Unblock WhatsApp user

Parameters:

  • token (String)

    JWT token or API key for authorization

  • block_user_request (BlockUserRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SuccessResponse, Integer, Hash)>)

    SuccessResponse data, response status code and response headers



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/one_msg_chat_api/api/users_api.rb', line 174

def unblock_user_with_http_info(token, block_user_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersApi.unblock_user ...'
  end
  # verify the required parameter 'token' is set
  if @api_client.config.client_side_validation && token.nil?
    fail ArgumentError, "Missing the required parameter 'token' when calling UsersApi.unblock_user"
  end
  # verify the required parameter 'block_user_request' is set
  if @api_client.config.client_side_validation && block_user_request.nil?
    fail ArgumentError, "Missing the required parameter 'block_user_request' when calling UsersApi.unblock_user"
  end
  # resource path
  local_var_path = '/unblockUser'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'token'] = token

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(block_user_request)

  # return_type
  return_type = opts[:debug_return_type] || 'SuccessResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['tokenAuth']

  new_options = opts.merge(
    :operation => :"UsersApi.unblock_user",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersApi#unblock_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end