Class: OneMsgChatApi::SendAddressMessageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OneMsgChatApi::SendAddressMessageRequest
- Defined in:
- lib/one_msg_chat_api/models/send_address_message_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Body text shown with the address request.
-
#chat_id ⇒ Object
Returns the value of attribute chat_id.
-
#country ⇒ Object
Address form country.
-
#phone ⇒ Object
Recipient phone (E.164 digits, no +).
-
#quoted_msg_id ⇒ Object
Returns the value of attribute quoted_msg_id.
-
#saved_addresses ⇒ Object
Optional previously saved addresses for the user.
-
#validation_errors ⇒ Object
Optional field validation errors when re-prompting.
-
#values ⇒ Object
Optional prefilled address fields.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendAddressMessageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendAddressMessageRequest
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgChatApi::SendAddressMessageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgChatApi::SendAddressMessageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'chat_id') self.chat_id = attributes[:'chat_id'] end if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'values') if (value = attributes[:'values']).is_a?(Hash) self.values = value end end if attributes.key?(:'saved_addresses') if (value = attributes[:'saved_addresses']).is_a?(Array) self.saved_addresses = value end end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Hash) self.validation_errors = value end end if attributes.key?(:'quoted_msg_id') self.quoted_msg_id = attributes[:'quoted_msg_id'] end end |
Instance Attribute Details
#body ⇒ Object
Body text shown with the address request
24 25 26 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 24 def body @body end |
#chat_id ⇒ Object
Returns the value of attribute chat_id.
21 22 23 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 21 def chat_id @chat_id end |
#country ⇒ Object
Address form country. Defaults to IN if omitted.
27 28 29 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 27 def country @country end |
#phone ⇒ Object
Recipient phone (E.164 digits, no +). Must match country.
19 20 21 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 19 def phone @phone end |
#quoted_msg_id ⇒ Object
Returns the value of attribute quoted_msg_id.
38 39 40 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 38 def quoted_msg_id @quoted_msg_id end |
#saved_addresses ⇒ Object
Optional previously saved addresses for the user
33 34 35 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 33 def saved_addresses @saved_addresses end |
#validation_errors ⇒ Object
Optional field validation errors when re-prompting
36 37 38 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 36 def validation_errors @validation_errors end |
#values ⇒ Object
Optional prefilled address fields
30 31 32 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 30 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 63 def self.attribute_map { :'phone' => :'phone', :'chat_id' => :'chatId', :'body' => :'body', :'country' => :'country', :'values' => :'values', :'saved_addresses' => :'saved_addresses', :'validation_errors' => :'validation_errors', :'quoted_msg_id' => :'quotedMsgId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 235 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 87 def self.openapi_types { :'phone' => :'Integer', :'chat_id' => :'String', :'body' => :'String', :'country' => :'String', :'values' => :'Hash<String, Object>', :'saved_addresses' => :'Array<Hash<String, Object>>', :'validation_errors' => :'Hash<String, Object>', :'quoted_msg_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && phone == o.phone && chat_id == o.chat_id && body == o.body && country == o.country && values == o.values && saved_addresses == o.saved_addresses && validation_errors == o.validation_errors && quoted_msg_id == o.quoted_msg_id end |
#eql?(o) ⇒ Boolean
222 223 224 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 222 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 228 def hash [phone, chat_id, body, country, values, saved_addresses, validation_errors, quoted_msg_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 183 |
# File 'lib/one_msg_chat_api/models/send_address_message_request.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @body.nil? country_validator = EnumAttributeValidator.new('String', ["IN", "SG"]) return false unless country_validator.valid?(@country) true end |