Class: OneMsgChatApi::SendFlowRequest1
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- OneMsgChatApi::SendFlowRequest1
- Defined in:
- lib/one_msg_chat_api/models/send_flow_request1.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#chat_id ⇒ Object
Returns the value of attribute chat_id.
-
#flow_action ⇒ Object
Returns the value of attribute flow_action.
-
#flow_action_data ⇒ Object
Returns the value of attribute flow_action_data.
-
#flow_action_payload ⇒ Object
Returns the value of attribute flow_action_payload.
-
#flow_action_screen ⇒ Object
Returns the value of attribute flow_action_screen.
-
#flow_cta ⇒ Object
Returns the value of attribute flow_cta.
-
#flow_id ⇒ Object
Returns the value of attribute flow_id.
-
#flow_message_version ⇒ Object
Returns the value of attribute flow_message_version.
-
#flow_token ⇒ Object
Returns the value of attribute flow_token.
-
#footer ⇒ Object
Returns the value of attribute footer.
-
#header ⇒ Object
Returns the value of attribute header.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#quoted_msg_id ⇒ Object
Returns the value of attribute quoted_msg_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendFlowRequest1
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendFlowRequest1
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneMsgChatApi::SendFlowRequest1` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneMsgChatApi::SendFlowRequest1`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'header') self.header = attributes[:'header'] end if attributes.key?(:'footer') self. = attributes[:'footer'] end if attributes.key?(:'flow_id') self.flow_id = attributes[:'flow_id'] else self.flow_id = nil end if attributes.key?(:'flow_token') self.flow_token = attributes[:'flow_token'] else self.flow_token = nil end if attributes.key?(:'flow_cta') self.flow_cta = attributes[:'flow_cta'] else self.flow_cta = nil end if attributes.key?(:'flow_action') self.flow_action = attributes[:'flow_action'] end if attributes.key?(:'flow_action_payload') self.flow_action_payload = attributes[:'flow_action_payload'] end if attributes.key?(:'flow_message_version') self. = attributes[:'flow_message_version'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'flow_action_data') self.flow_action_data = attributes[:'flow_action_data'] end if attributes.key?(:'flow_action_screen') self.flow_action_screen = attributes[:'flow_action_screen'] end if attributes.key?(:'quoted_msg_id') self.quoted_msg_id = attributes[:'quoted_msg_id'] end if attributes.key?(:'chat_id') self.chat_id = attributes[:'chat_id'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
18 19 20 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 18 def body @body end |
#chat_id ⇒ Object
Returns the value of attribute chat_id.
44 45 46 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 44 def chat_id @chat_id end |
#flow_action ⇒ Object
Returns the value of attribute flow_action.
30 31 32 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 30 def flow_action @flow_action end |
#flow_action_data ⇒ Object
Returns the value of attribute flow_action_data.
38 39 40 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 38 def flow_action_data @flow_action_data end |
#flow_action_payload ⇒ Object
Returns the value of attribute flow_action_payload.
32 33 34 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 32 def flow_action_payload @flow_action_payload end |
#flow_action_screen ⇒ Object
Returns the value of attribute flow_action_screen.
40 41 42 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 40 def flow_action_screen @flow_action_screen end |
#flow_cta ⇒ Object
Returns the value of attribute flow_cta.
28 29 30 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 28 def flow_cta @flow_cta end |
#flow_id ⇒ Object
Returns the value of attribute flow_id.
24 25 26 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 24 def flow_id @flow_id end |
#flow_message_version ⇒ Object
Returns the value of attribute flow_message_version.
34 35 36 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 34 def @flow_message_version end |
#flow_token ⇒ Object
Returns the value of attribute flow_token.
26 27 28 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 26 def flow_token @flow_token end |
#footer ⇒ Object
Returns the value of attribute footer.
22 23 24 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 22 def @footer end |
#header ⇒ Object
Returns the value of attribute header.
20 21 22 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 20 def header @header end |
#mode ⇒ Object
Returns the value of attribute mode.
36 37 38 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 36 def mode @mode end |
#phone ⇒ Object
Returns the value of attribute phone.
46 47 48 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 46 def phone @phone end |
#quoted_msg_id ⇒ Object
Returns the value of attribute quoted_msg_id.
42 43 44 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 42 def quoted_msg_id @quoted_msg_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 71 def self.attribute_map { :'body' => :'body', :'header' => :'header', :'footer' => :'footer', :'flow_id' => :'flowId', :'flow_token' => :'flowToken', :'flow_cta' => :'flowCta', :'flow_action' => :'flowAction', :'flow_action_payload' => :'flowActionPayload', :'flow_message_version' => :'flowMessageVersion', :'mode' => :'mode', :'flow_action_data' => :'flowActionData', :'flow_action_screen' => :'flowActionScreen', :'quoted_msg_id' => :'quotedMsgId', :'chat_id' => :'chatId', :'phone' => :'phone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 349 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 102 def self.openapi_types { :'body' => :'String', :'header' => :'SendFlowRequest1Header', :'footer' => :'String', :'flow_id' => :'String', :'flow_token' => :'String', :'flow_cta' => :'String', :'flow_action' => :'String', :'flow_action_payload' => :'Object', :'flow_message_version' => :'String', :'mode' => :'String', :'flow_action_data' => :'Object', :'flow_action_screen' => :'String', :'quoted_msg_id' => :'String', :'chat_id' => :'String', :'phone' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 314 def ==(o) return true if self.equal?(o) self.class == o.class && body == o.body && header == o.header && == o. && flow_id == o.flow_id && flow_token == o.flow_token && flow_cta == o.flow_cta && flow_action == o.flow_action && flow_action_payload == o.flow_action_payload && == o. && mode == o.mode && flow_action_data == o.flow_action_data && flow_action_screen == o.flow_action_screen && quoted_msg_id == o.quoted_msg_id && chat_id == o.chat_id && phone == o.phone end |
#eql?(o) ⇒ Boolean
336 337 338 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 336 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
342 343 344 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 342 def hash [body, header, , flow_id, flow_token, flow_cta, flow_action, flow_action_payload, , mode, flow_action_data, flow_action_screen, quoted_msg_id, chat_id, phone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 215 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end if @flow_id.nil? invalid_properties.push('invalid value for "flow_id", flow_id cannot be nil.') end if @flow_token.nil? invalid_properties.push('invalid value for "flow_token", flow_token cannot be nil.') end if @flow_cta.nil? invalid_properties.push('invalid value for "flow_cta", flow_cta cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 371 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/one_msg_chat_api/models/send_flow_request1.rb', line 239 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @body.nil? return false if @flow_id.nil? return false if @flow_token.nil? return false if @flow_cta.nil? flow_action_validator = EnumAttributeValidator.new('String', ["navigate", "data_exchange"]) return false unless flow_action_validator.valid?(@flow_action) mode_validator = EnumAttributeValidator.new('String', ["draft", "published"]) return false unless mode_validator.valid?(@mode) true end |